@@ -2,6 +2,35 @@ Q4 = {}
 Q5 = {}
 
 Q3 = {
+9:
+"""
+Дайте определение инвариантного линейного подпространства относительно линейного
+оператора.
+No9
+
+Линейное подпространство U ⊂ V называется инвариантным относительно линейного
+оператора φ : V → V , если φ(U) ⊂ U, т.е. U – инвариантно, если φ(x) ∈ U для ∀x ∈ U.
+
+ Будут ли ядро и образ линейного оператора инвариантными подпространствами? Ответ
+необходимо обосновать.
+
+Пусть φ: V→V – линейный оператор в конечномерном пространстве V. Определим ядро и
+образ линейного оператора как
+Ker(φ) = {x ∈ V: φ(x) = 0};
+Im(φ) = {y ∈ V: ∃x ∈ V такой, что φ(x) = y}.
+Ker(φ) и Im(φ) – инвариантные подпространства.
+Пусть y ∈ Im(φ) ⇒ ∃x ∈ V: φ(x) = y, так как φ: V→V, то (φ(x) = y) ∈ V и поэтому φ(φ(x)) = φ(y) ∈
+Im(φ), т.е. подпространство Im(φ)является инвариантным.
+Пусть x ∈ Ker(φ) ⇒ φ(x) = 0. Тогда φ(φ(x)) = φ(0) = 0, φ(x) ∈ Ker(φ), а значит
+подпространство Ker(φ) инвариантно.
+""",
+15:
+"""
+Любая квадратная матрица является корнем своего характерического многочлена.
+A = [[1,2],[3,4]], A - λ = [[1-λ,2],[3,4-λ]]
+найдем charpoly(A) : (1-λ)*(4-λ)-6= λ**2-5*λ-2
+подставим матрицу А в charpoly и убедимся, что после вычислений получим 0 : [[7,10],[15,22]] - [[5,10],[15,20]]-[[2,0],[0,2]] = [[0,0],[0,0]] ч.т.д
+""",
 14:
 """
 Теорема. • Пусть λ1, λ2, . . ., λs собственные значения, которые попарно различны. Тогда соответствующие им собственные векторы Х1, Х2, ..., Xs, – линейно независимы; • Если характеристический многочлен f(x) имеет n попарно различных действительных корней (n = dim V), то существует базис е', в котором A (матрица оператора) имеет диагональный вид; • Пусть V — вещественное линейное пространство и φ : V → V – линейный оператор. Пусть λ = ⍺ + i*ß, ß≠0 — комплексный корень характеристического уравнения fø(λ)=0. Тогда существуют пара линейно независимых векторов a,b ∈ V такие, что =
@@ -89,6 +118,67 @@ h_min = (-1)**3*f1/d
 }
 
 Q1 = {
+2:
+"""
+Редуцированной ступенчатой формой наз-ся ступенчатая матрица, если подматрица, составленная из всех ее основных (ведущих) столбцов  явл-ся единичной. 
+Теорема:
+Любую СЛАУ или же любую матрицу можно привести к редуцированному ступенчатому виду. 
+Неоднородная СЛАУ Ax=b будет совместной, если однородная СЛАУ является определенной или неопределенной при условии что в ступенчатой форме отсутствуют уравнения вида 0=b(i) при b(i) != 0. В первом случае мы получим в ступенчатой форме a(mn)x(n) = b(n) => x(n) = a(mn)/b(n). Подставляя в другие уравнения мы можем получить решение системы. Во втором случае если у нас в ступенчатой форме уравнения вида 0 = b(i) при b(i) != 0, то мы можем придать свободным переменным любые значения и выразить через них главные переменные
+""",
+5:
+"""
+Матрица - это объект, записываемый в виде прямоугольной таблице, который представляет собой совокупность строк и столбцов. Количество строк и столбцов задаёт размер матрицы. Матрица применяется для решения СЛАУ и СЛФР (систем линейных алгебраических и дифференциальных уравнений). Количество строк (m) определяет количество уравнений, а количество столбцов (n) - количество переменных. Для матриц определены операции: 
+сложение (если размеры матриц совпадают)
+умножение матриц подходящего размера (m*k) x (k*n) [если жирные значения равны, то получается матрица размером m * n - то есть, количество столбцов слева = количеству строк справа] 
+умножение матрицы на вектор столбец или строку (частный случай умножения матриц)
+умножение матрицы на число
+Симметрическая матрица - это квадратная матрица, которая равна себе транспонированной. Кососимметрическая матрица - это квадратная матрица, которая равна минус себе транспонированной. 
+
+Можно ли представить квадратную матрицу в виде суммы симметрической и кососимметрической? 
+Да, во-первых матрица квадратная, как и любая (косо)симметрическая матрица. Значит при их сложении мы получим квадратную матрицу. 
+ 
+Да, так как во первых слагаемые матрицы тоже будут квадратными, так как они 
+(косо)симметрические, а так же потому, что чтобы получить эти матрицы в симметрической надо поставить на ij и ji элементы полусумму ij и ji элементов изначальной матрицы, а в кососимметричную на  ij и ji элементы полуразность ij и ji элементов изначальной матрицы с разными знаками
+""",
+4:
+"""
+ФСР однородной СЛАУ. 
+Если ранг матрицы однородной СЛАУ равен r та такая система имеет n-r линейно независимых решений: фи(символ не вставляется)1, фи2,…,фиn-r. 
+Любая совокупность n-r линейно независимых решений однородной СЛАУ называется фундаментальной системой решений данной СЛАУ. 
+теорема об общем виде решения:
+решением СЛАУ называют набор значений неизвестных переменных (x1=a1, x2=a2,…,Xn = an), обращающий все уравнения системы в тождество. 
+Если решения фи1,фи2,…,фиn-r образуют ФСР, и X - матрица переменных данной СЛАУ, то общее решение СЛАУ можно представить в таком виде: X1 = C1* фи1+C2*фи2+…+Cn-r*фиn-r, где C1,C2,…,Cn-r - произвольные постоянные. Найдите ФСР 2*x1+3*X2-3*x3+4*x4-7*x5=0:
+так как  неизвестных 5 ранг матрицы[2,3,-3,4,-7] = 1, то ФСР состоит из 5-1 векторов. 
+x1+ 3/2*x2 - 3/2*x3 +4/2*x4 -7/2*x5=0 
+выражаем x через оставшиеся 
+x1 = -3/2*x2 +3/2 *x3 -2*x4 +7/2*x5 
+фср: e1= [-3/2, 1 , 0 , 0, 0].T , e2 = [3/2,0,1,0,0].T, e3 = [-2,0,0,1,0].T, e4 = [7/2,0,0,0,1].T
+""",
+9:
+"""
+Понятие элементарной матрицы
+Квадратичная матрица, получающаяся из единичной матрицы в результате одного элементарного преобразования называется
+элементарной матрицей, соответствующей этому преобразованию.
+p(ij)-1 == p(ij)
+док-во:Умножение на элементарную матрицу P(ij) соответствует преобразованию "перестановка i-ой и j-ой строк (при умножении слева,
+справа для перестановки столбцов)", т.е. матрица P(ij) получается из единичной матрицы в результате перестановки её i-ой и j-ой
+строк. => при перестановке i-ой и j-ой строк в матрице P(ij), т.е. при умножении ее на матрицу P(ij), получается единичная матрица. =>
+матрица P(ij) является обратной к матрице P(ij).
+Mi(a)-1 == Mi(1/a)
+док-во: Умножение на элементарную матрицу M(i)(α) соответствует преобразованию "умножение i-ой строки а α", т.е. матрица M(i)(α)
+получается из единичной матрицы в результате умножения i-ой строки на α. => при умножении i-ой строки на (1/α) получается
+единичная матрица => матрица M(i)(1/α) является обратной к матрице M(i)(α).
+[Aji(a)]**-1 == Aji(-a)
+док-во: 
+Умножение на элементарную матрицу A(ji)(α) соответствует преобразованию "прибавление к j-ой строке i-ую строку, умноженную на
+α (при умножении на матрицу слева)", т.е. матрица A(ji)(α) получается из единичной матрицы в результате прибавления к j-ой строке
+i-ую строку, умноженную на α. => при прибавлении к j-ой строке i-ую строку, умноженную на (-α) получается единичная матрица =>
+матрица A(ji)(-α) является обратной к матрице A(ji)(α).
+примеры: 
+I = eye(3)
+P12 = Matrix([[0, 1, 0], [1, 0, 0], [0, 0, 1]]) # элементарная матрица "перестановка 1-ой и 2-ой строк"
+P12, P12*P12
+""",
     1: """СЛАУ - это система m уравнений n переменных, каждое уравнение в которой является линейным (то есть первой степени). СЛАУ является однородной, если все свободные члены = 0. Неоднородной в другом случае. (Определитель неоднородной системы = 0). СЛАУ называется определенной, если у неё есть только единственное решение, иначе она называется неопределенной. СЛАУ является линейно зависимой, если некоторую строку можно представить в виде комбинации других строк. Иначе, она является независимой. Если система является линейно независимой, то она не может быть неопределенной. Если система является линейно зависимой, то она может быть как определенной, так и неопределенной. """,
     3: """Рангом матрицы называют максимальное число линейно независимых строк (т.е тех, которых нельзя представить в виде других строк, они же - единичные строки). Система является совместной, если у неё есть хотя бы одно решение и несовместной, если решений нет. Теорема Кронекера-Капелли гласит, что СЛАУ является совместной ⇔ ранг основной матрицы равен рангу её расширенной матрицы. Расширенная матрица - это матрица, которой справа дописали ещё столбец свободных членов.
 
